summaryrefslogtreecommitdiffstats
path: root/remote/lib/print.sh
diff options
context:
space:
mode:
Diffstat (limited to 'remote/lib/print.sh')
-rw-r--r--remote/lib/print.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/remote/lib/print.sh b/remote/lib/print.sh
index 465fce5..a0fdcbe 100644
--- a/remote/lib/print.sh
+++ b/remote/lib/print.sh
@@ -73,13 +73,14 @@ function configure_palete {
foreground="white"
;;
*)
# Yellow is invisible on white
colors[yellow]=${colors[orange]}
+ colors[white]=${colors[black]}
+ colors[lightgray]=${colors[gray]}
colors[cyan]=${colors[blue]}
;;
esac
- clear
set_background
reset_color
}
@@ -164,5 +165,4 @@ function print_status {
echo -n " "
}
-
-configure_palete "$palete"
+clear
@@ -73,13 +73,14 @@ function configure_palete {
;;
*)
- # Yellow is invisible on white
+ # Lightgray and Yellow are almost invisible on white
colors[yellow]=${colors[orange]}